assists in finding level or description mismatches in a set parameter(tables)
sii_debug_geom(data_descriptionvector,
structure = ggsolvencyii::sii_structure_sf16_eng,
aggregatesuffix = "other", levelmax = NULL, plotdetails = NULL,
fillcolors = NULL, edgecolors = NULL)(no default) the vector 'description' from the data
(no default) the structure dataframe
(optional, default = "_other"):
(optional, no default): the levelmax dataframe, when not filled the expanded structure assumes levelmax was set to 99 for all levels.
(optional, no default): the plotdetails dataframe
(optional, no default): fillcolor parameter (list with items "description" = "color" where color can be a name, #hexcode or other )
(optional, no default): edgecolor parameter (list with items "description" = "color" where color can be a name, #hexcode or other )
prints two comparison tables and puts them in $debug_description and $debug_level