powered by
a adapted (compact) structure, for a life-insurer with only market and life risk and their subrisks
sii_z_ex1_structure
A data frame with columns:
string: the name of the component, or a diversification
string with format 'level(numeric)' [<point> 'sublevel(numeric)'] ['d'] i.e. 1, 2.01, 3.1d where d indicates a diversification component
string of the same format as level, indicating the level of which the components make up this item
# NOT RUN { installedtable <- sii_z_ex1_structure installedtable # }
Run the code above in your browser using DataLab