Learn R Programming

ggsolvencyii (version 0.1.2)

sii_z_ex2_data: sii_z_ex2_data

Description

example dataset, in tidyverse format, with only one instance of a limited filled sf structure.

Usage

sii_z_ex2_data

Arguments

Format

A data frame with columns:

time

numerical: a representation of an x value: The x aesthetic could also be a normal numbering, or a longitude

ratio

numerical: solvency II ratio, a representation of an y value: y aesthetic could also be a lattitude

description

character: component of the structure

id

number: a grouping item

value

numerical: positive for risks, negative for diversification effects

Examples

Run this code
# NOT RUN {
installedtable <- sii_z_ex2_data
installedtable
# }

Run the code above in your browser using DataLab