Learn R Programming

ggsolvencyii (version 0.1.2)

sii_z_ex3_plotdetails: sii_z_ex3_plotdetails #' A table for geom_sii_risksurface and geom_sii_riskoutline indicating which outlines of each item should be shown, specified per level and/or description. the latter overrule the former. when defining an item (or the squared = TRUE transformation) 4 lines can be distinguished, a radialline going outwards, a circle segment (clockwise), a radialline going inwards, a circle segment (counterclockwise). These are numbered as outline1 to outline4.

Description

sii_z_ex3_plotdetails #' A table for geom_sii_risksurface and geom_sii_riskoutline indicating which outlines of each item should be shown, specified per level and/or description. the latter overrule the former. when defining an item (or the squared = TRUE transformation) 4 lines can be distinguished, a radialline going outwards, a circle segment (clockwise), a radialline going inwards, a circle segment (counterclockwise). These are numbered as outline1 to outline4.

Usage

sii_z_ex3_plotdetails

Arguments

Format

A data frame with columns:

levelordescription

string with format 'level(numeric)' [<point> 'sublevel(numeric)'] ['d'] i.e. 1, 2.01, 3.1d where d indicates a diversification component AND/OR description(s) from the corresponding structure

surface

boolean (logical): the surface

outline1

boolean (logical): the radial line

outline2

boolean (logical): the outer line

outline3

boolean (logical): the radial line

outline4

boolean (logical): the inner line

outline11

NOT YET IMPLEMENTED: boolean (logical): analogue to outline1, but but only for the first plotted component of that level. The components in each level are plotted clockwise

outline13

NOT YET IMPLEMENTED: boolean (logical): analogue to outline3, but but only for the last plotted component of that level.

Examples

Run this code
# NOT RUN {
installedtable <- sii_z_ex3_plotdetails
installedtable
# }

Run the code above in your browser using DataLab