Learn R Programming

ggsolvencyii (version 0.1.2)

sii_z_ex4_structure: sii_z_ex4_structure

Description

a adapted (compact) structure with no division of market, life, .. risks in subrisks (i.e. equity, longevity,... ). Descriptions are in English

Usage

sii_z_ex4_structure

Arguments

Format

A data frame with columns:

description

string: the name of the component, or a diversification

level

string with format 'level(numeric)' [<point> 'sublevel(numeric)'] ['d'] i.e. 1, 2.01, 3.1d where d indicates a diversification component

childlevel

string of the same format as level, indicating the level of which the components make up this item

Examples

Run this code
# NOT RUN {
installedtable <- sii_z_ex4_structure
installedtable
# }

Run the code above in your browser using DataLab