Learn R Programming

ggsolvencyii (version 0.1.2)

sii_z_ex6_data: sii_z_ex6_data

Description

example dataset of a internal model of a large Dutch insurer (NN group). Values are fictious

Usage

sii_z_ex6_data

Arguments

Format

A data frame with columns:

time

numerical: a representation of an x value: The x aesthetic could also be a normal numbering, or a longitude

ratio

numerical: solvency II ratio, a representation of an y value: y aesthetic could also be a lattitude

description

character: component of the structure

id

number: a grouping item

value

numerical: positive for risks, negative for diversification effects

comparewithid

numerical: a reference to the id of another datapoint

Examples

Run this code
# NOT RUN {
installedtable <- sii_z_ex6_data
installedtable
# }

Run the code above in your browser using DataLab