Learn R Programming

ggsolvencyii (version 0.1.2)

sii_z_ex6_data2: sii_z_ex6_data2

Description

example dataset of a internal model of a large Dutch insurer (NN group). Values are fictious. To show 'counterparty default risk (CPD)' separate from the two components 'type 1' and 'type 2' the following assumption is made: The (fictious) diversification towards the higher level from CPD risk is transferred to a position between CPD and its two components. A similar approach is used to show 'business risk', 'life risk', 'morbidity risk' and 'non-life risk' and their (7,4,4 and 4) components

Usage

sii_z_ex6_data2

Arguments

Format

A data frame with columns:

time

numerical: a representation of an x value: The x aesthetic could also be a normal numbering, or a longitude

ratio

numerical: solvency II ratio, a representation of an y value: y aesthetic could also be a lattitude

description

character: component of the structure

id

number: a grouping item

value

numerical: positive for risks, negative for diversification effects

comparewithid

numerical: a reference to the id of another datapoint

#'

Examples

Run this code
# NOT RUN {
installedtable <- sii_z_ex6_data2
installedtable
# }

Run the code above in your browser using DataLab