maximum number of items in a level, 99 items for levels 1-3 (SCR, BSCR/OR/ADJ, Market/life/... risks) and 3 items for lower level risk (equity/longevity/...) in a standard formula structure.
Usage
sii_levelmax_sf16_993
Arguments
Format
A data frame with columns:
level
string with format 'level(numeric)' [<point> 'sublevel(numeric)'] ['d'] i.e. 1, 2.01, 3.1d where d indicates a diversification component
levelmax
positive integer indicating the total number of components to be shown in a level, consisting of the x-1 largest components and the remaining components combined in one other