powered by
example dataset, in tidyverse format, with only one instance of a limited filled sf structure.
sii_z_ex2_data
A data frame with columns:
numerical: a representation of an x value: The x aesthetic could also be a normal numbering, or a longitude
numerical: solvency II ratio, a representation of an y value: y aesthetic could also be a lattitude
character: component of the structure
number: a grouping item
numerical: positive for risks, negative for diversification effects
# NOT RUN { installedtable <- sii_z_ex2_data installedtable # }
Run the code above in your browser using DataLab