powered by
a adapted (compact) structure with no division of market, life, .. risks in subrisks (i.e. equity, longevity,... ). Descriptions are in English
sii_z_ex4_structure
A data frame with columns:
string: the name of the component, or a diversification
string with format 'level(numeric)' [<point> 'sublevel(numeric)'] ['d'] i.e. 1, 2.01, 3.1d where d indicates a diversification component
string of the same format as level, indicating the level of which the components make up this item
# NOT RUN { installedtable <- sii_z_ex4_structure installedtable # }
Run the code above in your browser using DataLab