powered by
example dataset of a internal model of a large Dutch insurer (NN group). Values are fictious
sii_z_ex6_data
A data frame with columns:
numerical: a representation of an x value: The x aesthetic could also be a normal numbering, or a longitude
numerical: solvency II ratio, a representation of an y value: y aesthetic could also be a lattitude
character: component of the structure
number: a grouping item
numerical: positive for risks, negative for diversification effects
numerical: a reference to the id of another datapoint
# NOT RUN { installedtable <- sii_z_ex6_data installedtable # }
Run the code above in your browser using DataLab